pub struct TokenBucket { /* private fields */ }Expand description
Token-bucket rate-limit throttle.
Implementations
Sourceimpl TokenBucket
impl TokenBucket
Sourcepub fn new(rate_bytes_per_sec: u64) -> Self
pub fn new(rate_bytes_per_sec: u64) -> Self
Construct a new throttle at rate_bytes_per_sec. The throttle’s clock
starts at construction time.
Sourcepub fn next_sleep(&self, bytes_done: u64) -> Duration
pub fn next_sleep(&self, bytes_done: u64) -> Duration
Inspect whether the loop is currently over-budget and, if so, return
the recommended sleep duration to converge to the rate. Returns
Duration::ZERO when the throttle is happy with current progress.
Sourcepub fn maybe_sleep(&self, bytes_done: u64) -> bool
pub fn maybe_sleep(&self, bytes_done: u64) -> bool
Sleep for the recommended interval if any. Returns true if a sleep
was performed, false if no sleep was needed.